DecodeError

Struct DecodeError 

pub struct DecodeError {
    pub instruction: u32,
    pub unexpected_field: &'static str,
}
The error used for invalid instructions containing information about the instruction and error.

Note that this is also returned for the defined illegal instruction of all zero.

Fields

instruction: u32

The instruction bytes that failed to decode.

unexpected_field: &'static str

Which field of the instruction contained unexpected bits.