Imm

Struct Imm 

pub struct Imm(/* private fields */);
An immediate in an instruction. This represents the real value that will be put in the register, so sign extension has been performed if necessary, and for instructions like lui the value will have been shifted.

This type is XLEN-agnostic, use the XLEN-specific accessors to get the correct value.

Implementations

Source

impl Imm

pub const ZERO: Self

The immediate 0. Useful as a shortcut for Imm::new_u32(0) and for patterns.

pub const fn new_i32(value: i32) -> Self

Create a new immediate from the (if necessary) sign-extended value.

pub const fn new_u32(value: u32) -> Self

Create a new immediate from the (if necessary) zero-extended value.

pub const fn as_u32(self) -> u32

Get the u32 (RV32) value of the immediate.

pub const fn as_i32(self) -> i32

Get the i32 (RV32) value of the immediate.

pub const fn as_u64(self) -> u64

Get the u64 (RV64) value of the immediate.

pub const fn as_i64(self) -> i64

Get the i64 (RV64) value of the immediate.