pub enum IsCompressed {
No,
Yes,
}Expand description
Whether the decoded instruction was a compressed instruction or not. If it was compressed, only the first two bytes were used. If it was not compressed, all four bytes are consumed.
Variants